searchData={"content_type":"text/markdown","items":[{"doc":"# Scrivener.Ecto\n\n[![Build\nStatus](https://github.com/mojotech/scrivener_ecto/actions/workflows/test.yml/badge.svg?branch=master)](https://github.com/mojotech/scrivener_ecto/actions/workflows/test.yml)","ref":"readme.html","title":"Scrivener.Ecto","type":"extras"},{"doc":"This library is in low maintenance mode, which means the author is currently only responding to pull requests and breaking issues.","ref":"readme.html#low-maintenance-warning","title":"Low Maintenance Warning - Scrivener.Ecto","type":"extras"},{"doc":"Scrivener.Ecto allows you to paginate your Ecto queries with Scrivener. It gives you useful information such as the total number of pages, the current page, and the current page's entries. It works nicely with Phoenix as well.\n\nFirst, you'll want to `use` Scrivener in your application's Ecto Repo. This will add a `paginate` function to your Repo. This `paginate` function expects to be called with, at a minimum, an Ecto query. It will then paginate the query and execute it, returning a `Scrivener.Page`. Defaults for `page_size` can be configured when you `use` Scrivener. If no `page_size` is provided, Scrivener will use `10` by default.\n\nYou may also want to call `paginate` with a params map along with your query. If provided with a params map, Scrivener will use the values in the keys `\"page\"` and `\"page_size\"` before using any configured defaults.\n\nNote: Scrivener.Ecto only supports Ecto backends that allow subqueries (e.g. PostgreSQL).","ref":"readme.html#usage","title":"Usage - Scrivener.Ecto","type":"extras"},{"doc":"```elixir\ndefmodule MyApp.Repo do\n  use Ecto.Repo, otp_app: :my_app, adapter: Ecto.Adapters.Postgres\n  use Scrivener, page_size: 10\nend\n```\n\n```elixir\ndefmodule MyApp.Person do\n  use Ecto.Schema\n\n  schema \"people\" do\n    field :name, :string\n    field :age, :integer\n\n    has_many :friends, MyApp.Person\n  end\nend\n```\n\n```elixir\ndef index(conn, params) do\n  page =\n    MyApp.Person\n    |> where([p], p.age > 30)\n    |> order_by(desc: :age)\n    |> preload(:friends)\n    |> MyApp.Repo.paginate(params)\n\n  render conn, :index,\n    people: page.entries,\n    page_number: page.page_number,\n    page_size: page.page_size,\n    total_pages: page.total_pages,\n    total_entries: page.total_entries\nend\n```\n\n```elixir\npage =\n  MyApp.Person\n  |> where([p], p.age > 30)\n  |> order_by(desc: :age)\n  |> preload(:friends)\n  |> MyApp.Repo.paginate(page: 2, page_size: 5)\n```","ref":"readme.html#example","title":"Example - Scrivener.Ecto","type":"extras"},{"doc":"Add `scrivener_ecto` to your `mix.exs` `deps`.\n\n```elixir\ndefp deps do\n  [\n    {:scrivener_ecto, \"~> 3.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Scrivener.Ecto","type":"extras"},{"doc":"First, you'll need to build the test database.\n\n```bash\nMIX_ENV=test mix db.reset\n```\n\nThis task assumes you have Postgres installed and that the `postgres` user can create / drop databases. If you'd prefer to use a different user, you can specify it with the environment variable `SCRIVENER_ECTO_DB_USER`.\n\nAlternatively, if you prefer to use Docker for database setup.\n\n```bash\ndocker-compose up\n```\n\nWith the database built, you can now run the tests.\n\n```elixir\nmix test\n```","ref":"readme.html#contributing","title":"Contributing - Scrivener.Ecto","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}